==> d2c-6.x-1.1.tar.gz: d2c/d2c_analytics/d2c_analytics_main_consumer/d2c_analytics_main_consumer_d2c_code.tpl.php <==
<div class="d2c-analytics-main-consumer-d2c-code">
  <img class="d2c-qr-code" id="d2c-qr-code-<?php print $code->local_id ?>" src="<?php print d2c_settings_code_image_path($code) ?>" />
  <div class="info">
    <div class="name"><?php print t('D2C QR code:') . ' ' . $code->name ?></div>
    <div><span class="header"><?php print t('Type') ?>:</span> <?php $types = D2CApi::code_types(); print $types[$code->code_type] ?></div>
    <div><span class="header"><?php print t('Behaviour') ?>:</span> <?php $behaviours = D2CCode::behaviours(); print $behaviours[$code->behaviour] ?></div>
    <div><span class="header"><?php print t('Domain') ?>:</span> <?php print D2CDomain::find($code->domain_id)->name ?></div>
    <?php if ($code->campaign_id) :?>
      <div><span class="header"><?php print t('Campaign') ?>:</span> <?php print D2CCampaign::find($code->campaign_id)->name ?></div>
    <?php endif ?>
  </div>
  <div class="buttons">
    <a href="/admin/settings/d2c/codes/<?php print $code->local_id ?>/edit">edit</a> ·
    <a href="#" onclick="$('#d2c_node_toggle_activation_code_form_<?php print $code->local_id ?>').submit();"><?php print($code->active ? t('deactivate') : t('activate')) ?></a> ·
    <a href="/admin/settings/d2c/codes/<?php print $code->local_id ?>/delete"><?php print(t('delete')) ?></a>
    <form id="d2c_node_toggle_activation_code_form_<?php print $code->local_id ?>" action="/admin/settings/d2c/codes/<?php print $code->local_id ?>/toggle_activation">
      <input type="hidden" name="destination" value="/admin/settings/d2c/stats?<?php print drupal_query_string_encode($_GET, array('q')) ?>" />
    </form>
  </div>
</div>

==> d2c-6.x-1.6.tar.gz: d2c/d2c_analytics/d2c_analytics_main_consumer/d2c_analytics_main_consumer_d2c_code.tpl.php <==
<div class="d2c-analytics-main-consumer-d2c-code">
  <img class="d2c-qr-code" id="d2c-qr-code-<?php print $code->local_id ?>" src="<?php print d2c_settings_code_image_path($code) ?>" />
  <div class="info">
    <div class="name"><?php print t('D2C QR code:') . ' ' . $code->name ?></div>
    <div><span class="header"><?php print t('Type') ?>:</span> <?php $types = D2CApi::code_types(); print $types[$code->code_type] ?></div>
    <div><span class="header"><?php print t('Behaviour') ?>:</span> <?php $behaviours = D2CCode::behaviours(); print $behaviours[$code->behaviour] ?></div>
    <div><span class="header"><?php print t('Domain') ?>:</span> <?php print D2CDomain::find($code->domain_id)->name ?></div>
    <?php if ($code->campaign_id) :?>
      <div><span class="header"><?php print t('Campaign') ?>:</span> <?php print D2CCampaign::find($code->campaign_id)->name ?></div>
    <?php endif ?>
  </div>
  <div class="buttons">
    <a href="<?php print url('admin/settings/d2c/codes/' . $code->local_id . '/edit') ?>">edit</a> ·
    <a href="#" onclick="$('#d2c_node_toggle_activation_code_form_<?php print $code->local_id ?>').submit();"><?php print($code->active ? t('deactivate') : t('activate')) ?></a> ·
    <a href="<?php print url('admin/settings/d2c/codes/' . $code->local_id . '/delete') ?>"><?php print(t('delete')) ?></a>
    <form id="d2c_node_toggle_activation_code_form_<?php print $code->local_id ?>" action="<?php print url('admin/settings/d2c/codes/' . $code->local_id . '/toggle_activation') ?>" method="post">
      <input type="hidden" name="destination" value="/admin/settings/d2c/stats?<?php print drupal_query_string_encode($_GET, array('q')) ?>" />
    </form>
  </div>
</div>
